@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2002, 2007, 2009-2012, 2014-2018 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999-2020 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -181,6 +180,7 @@ pop_input (mu_list_t list, int *state, const char **input)
   *state = inp->state;
   if (input)
     *input = inp->input;
+  free (inp);
   return 0;
 }
 
@@ -325,7 +325,7 @@ mu_scan_datetime (const char *input, const char *fmt,
 #endif
   /* provide default timezone, in case it is not supplied in input */
   if (tz)
-    mu_datetime_tz_local (tz);
+    mu_datetime_tz_utc (tz);
 
   /* Skip leading whitespace */
   input = mu_str_skip_class (input, MU_CTYPE_BLANK);
